@@ -261,24 +261,25 @@ class CheckBoxElement(ScreenElement):
 class TableElement(ScreenElement):
     """
     class TableRowModel(object):
-        TITLE = 'td:nth-child(1)'
-        WORK = 'td:nth-child(2)'
-        SALARY = 'td:nth-child(3)'
 
         def __init__(self, container):
             self.driver = container
+            self.tag = 'th' if self.driver.find_elements('xpath', './th') else 'td'
+            self._author = f'{self.tag}:nth-child(1)'
+            self._course = f'{self.tag}:nth-child(2)'
+            self._price = f'{self.tag}:nth-child(3)'
 
         @property
         def author(self):
-            return self.driver.find_element_by_css_selector(self.TITLE).text
+            return self.driver.find_element_by_css_selector(self._author).text
 
         @property
         def course(self):
-            return self.driver.find_element_by_css_selector(self.WORK).text
+            return self.driver.find_element_by_css_selector(self._course).text
 
         @property
-        def salary(self):
-            return self.driver.find_element_by_css_selector(self.SALARY).text
+        def price(self):
+            return self.driver.find_element_by_css_selector(self._price).text
     """
 
     def __init__(self, table_rows_locator, table_row_model_cls):
@@ -293,7 +294,7 @@ class TableElement(ScreenElement):
             condition=ec.presence_of_all_elements_located)]
         """
         self._refresh(obj)
-        table_rows = [self._table_entry_cls(table_row) for table_row in self.driver]
-        header = table_rows[1]
-        rows = table_rows[1:]
-        return {'table_rows': table_rows, 'header': header, 'rows': rows}
+        all_table_rows = [self._table_entry_cls(table_row) for table_row in self.driver]
+        table_headers = list(filter(lambda row: (row.driver.find_elements('xpath', './th')), all_table_rows))
+        table_rows = list(filter(lambda row: (row.driver.find_elements('xpath', './td')), all_table_rows))
+        return {'all_rows': all_table_rows, 'headers': table_headers, 'rows': table_rows}
