@@ -1,5 +1,6 @@
 import configparser
 import inspect
+import os
 from pathlib import Path
 
 
@@ -13,7 +14,7 @@ def locate_file(dir_path, file):
     return file_path
 
 
-def load_config(directory):
+def load_config(directory=Path(os.getcwd()).parent):
     file_path = locate_file(directory, 'poe.ini')
     if file_path:
         config = configparser.ConfigParser()
